/*
 *---------------------------------------------------------------------
 *            Copyright 1990 University of New Mexico
 * 
 * Permission to copy and modify this software and its documen- 
 * tation only for internal use in your organization is hereby 
 * granted, provided that this notice is retained thereon and 
 * on all copies.  UNM makes no representations as too the sui- 
 * tability and operability of this software for any purpose. 
 * It is provided 'as is' without express or implied warranty. 
 *  
 * UNM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, 
 * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FIT- 
 * NESS.  IN NO EVENT SHALL UNM BE LIABLE FOR ANY SPECIAL, 
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY OTHER DAMAGES WHAT- 
 * SOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER 
 * IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS 
 * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PER- 
 * FORMANCE OF THIS SOFTWARE. 
 *  
 * No other rights, including for example, the right to redis- 
 * tribute this software and its documentation or the right to 
 * prepare derivative works, are granted unless specifically 
 * provided in a separate license agreement. 
 * 
 *---------------------------------------------------------------------
 */

/*>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>  <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 >>>>
 >>>>         File Name:  form_info.h
 >>>>
 >>>>      Program Desc:  structure in which values extracted
 >>>>                      from the graphical user interface are stored
 >>>>
 >>>>            Author:  automatically generated by conductor
 >>>>
 >>>> Date Last Updated:  Mon Feb 18 16:13:05 1991
 >>>>
 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>   <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<*/

typedef struct {

        char *infile;
        int infile_index;

        int add_file;
        int add_file_index;

        int delete_file;
        int delete_file_index;

        int get_input;
        int get_input_index;

} Subform1_input;



typedef struct {

        char *outfile;
        int outfile_index;
        int outfile_selected;

        int save_output;
        int save_output_index;

} Subform1_output;

typedef struct {

        int operation;

        Subform1_input  *input;
        int input_selected;
        int input_index;
        int input_gb_index;

        Subform1_output  *output;
        int output_selected;
        int output_index;
        int output_gb_index;

        int quit;

}  Master_Subform1;


typedef struct {

        int trans_type_val;
        int trans_type_index;

        float x_val;
        int x_val_index;

        float y_val;
        int y_val_index;

        int int2;
        int int2_index;

        int int1;
        int int1_index;

        char *string1;
        int string1_index;
        int string1_selected;

        char *string2;
        int string2_index;
        int string2_selected;

        char *string3;
        int string3_index;
        int string3_selected;

        int int4;
        int int4_index;
        int int4_selected;

        int do_something;
        int do_something_index;

        int quit;

} Subform2_transforms;

typedef struct {

        Subform2_transforms  *transforms;
        int transforms_selected;
        int transforms_index;
        int transforms_gb_index;

}  Master_Subform2;


typedef struct { 

        int master_action;

        int workspace_index;

        Widget workspace;

        Master_Subform1  *Subform1;
        int Subform1_selected;
        int Subform1_index;
        int Subform1_sfb_index;

        Master_Subform2  *Subform2;
        int Subform2_selected;
        int Subform2_index;
        int Subform2_sfb_index;

        int quit;


 }  Master; 

