/**/## Beginning of the Khoros generic toolbox configuration file 

/* 
 *  This file is included in the Makefile after Khoros.tmpl, 
 *  Site.def, Library.def file and just before the Imakefile.
 *  This file can be modified to define other Toolbox definitions.
 */

/* assign a variable to the name of your particular toolbox */
EXAMPLE_TB = EXAMPLE_TOOLBOX

/* set locations of bin and lib directories in your particular toolbox */
LIBDIR = $(EXAMPLE_TB)/lib
BINDIR = $(EXAMPLE_TB)/bin

/* set library loading search path - these should be left alone */
TOOLBOXLIBDIR = -L$(LIBDIR)

/* set location of include files in your particular toolbox */
TOOLBOXINCLUDE = -I$(EXAMPLE_TB)/include

/* any special defines for your toolbox (eg, #ifdef DEBUG) 
   can be set here (eg, -DDEBUG) */
TOOLBOXDEFINES = /**/

/* list C libraries created (by you) in toolbox */
TOOLBOX_LIBRARIES = -lexample
TOOLBOX_DEP_LIBRARIES =  $(LIBDIR)/libexample.a

/* list FORTRAN libraries created (by you) in toolbox */
FOR_TOOLBOX_LIBRARIES = /**/
FOR_TOOLBOX_DEP_LIBRARIES = /**/


/* list Xlib or X Toolkit dependant libaries create (by you) in toolbox */
X_TOOLBOX_LIBRARIES = /**/
X_TOOLBOX_DEP_LIBRARIES = /**/
