KCOM Beginning of the Khoros generic toolbox configuration file 

/* 
 *  This file is included after Khoros.tmpl, Site.def and
 *  the Library.def file and  just before the Imakefile.
 *  This file can be modified to define global Toolbox 
 *  definitions.
 */

TOOLBOXLIBDIR = /**/

TOOLBOXINCLUDE =  /**/

TOOLBOXDEFINES = /**/


TOOLBOX_LIBRARIES = /**/

FOR_TOOLBOX_LIBRARIES = /**/

X_TOOLBOX_LIBRARIES = /**/


TOOLBOX_DEP_LIBRARIES = /**/

FOR_TOOLBOX_DEP_LIBRARIES = /**/

X_TOOLBOX_DEP_LIBRARIES = /**/
