KCOM Beginning of Khoros library configuration file -  Library.def.

/*
 * Library imakefile info  - this contains any special redefinitions, etc.
 * that Imakefiles in the various library subtrees will need.
 */

/*
 * specify the system libraries that your machine uses.
 * if SysLibs is defined in the machine.cf file, that will
 * over ride this definition
 */
#ifndef SysLibs
#define SysLibs	-lm -ll
#endif

/*
 * specify the X libraries that your machine uses.
 * if XLibs is defined in the machine.cf file, that will
 * over ride this definition
 */
#ifndef XLibs
#define XLibs	-lXaw -lXmu -lXt -lXext -lX11
#endif

/*
 * specify the Fortran libraries that your machine uses.
 * Note, if your machine supports fortran, then
 * set HasFortran to YES in the machine.cf or the
 * Site.def file. if ForSysLibs is defined in the machine.cf file, 
 * that will over ride this definition
 */
#if HasFortran
#ifndef ForSysLibs
#define ForSysLibs	-lF77 -lI77
#endif
#else
#define ForSysLibs      /**/
#endif


/* 
 * if you have extra libs that you want to link against,
 * specify them here. ExtraLibs always is last on the
 * list of libraries
 */

#ifndef ExtraLibs
#define ExtraLibs	/**/
#endif

/* LIBDIR is used as the directory for installing libs into, so for
 * Khoros set LIBDIR to KLIBDIR
 */

          LIBDIR = $(KLIBDIR)

/* 
 * The following library definitions should not normally be touched.
 * If you are installing a new library in Khoros add it below. 
 */


      NUM_ANALLIB = -lnum_anal
          DSPLLIB = -ldspl
    FILEFORMATLIB = -lformat
      GEO_SURFLIB = -lgeo_surf
         GHOSTLIB = -lghost
         VEXPRLIB = -lvexpr
       LINPACKLIB = -llinpack
       EISPACKLIB = -leispack
          TIFFLIB = -ltiff
         VMATHLIB = -lvmath
        VERRORLIB = -lverror
        VGPARMLIB = -lvgparm
          VIPLLIB = -lvipl
         VRASTLIB = -lvrast
        VUTILSLIB = -lvutils
     XVDISPLAYLIB = -ldisplay
       XVFORMSLIB = -lxvforms
    XVGRAPHICSLIB = -lgraphics
      XVPARSERLIB = -lxvparser
        XVPLOTLIB = -lxvplot
       XVUTILSLIB = -lxvutils


DEPENDNUM_ANALLIB = $(KLIBDIR)/libnum_anal.a
    DEPENDDSPLLIB = $(KLIBDIR)/libdspl.a
DEPENDFILEFORMATLIB = $(KLIBDIR)/libformat.a
DEPENDGEO_SURFLIB = $(KLIBDIR)/libgeo_surf.a
   DEPENDVEXPRLIB = $(KLIBDIR)/libvexpr.a
   DEPENDGHOSTLIB = $(KLIBDIR)/libghost.a
 DEPENDLINPACKLIB = $(KLIBDIR)/liblinpack.a
 DEPENDEISPACKLIB = $(KLIBDIR)/libeispack.a
    DEPENDTIFFLIB = $(KLIBDIR)/libtiff.a
   DEPENDVMATHLIB = $(KLIBDIR)/libvmath.a
  DEPENDVERRORLIB = $(KLIBDIR)/libverror.a
  DEPENDVGPARMLIB = $(KLIBDIR)/libvgparm.a
    DEPENDVIPLLIB = $(KLIBDIR)/libvipl.a
   DEPENDVRASTLIB = $(KLIBDIR)/libvrast.a
  DEPENDVUTILSLIB = $(KLIBDIR)/libvutils.a
DEPENDXVDISPLAYLIB = $(KLIBDIR)/libdisplay.a
 DEPENDXVFORMSLIB = $(KLIBDIR)/libxvforms.a
DEPENDXVGRAPHICSLIB = $(KLIBDIR)/libgraphics.a
DEPENDXVPARSERLIB = $(KLIBDIR)/libxvparser.a
  DEPENDXVPLOTLIB = $(KLIBDIR)/libxvplot.a
 DEPENDXVUTILSLIB = $(KLIBDIR)/libxvutils.a


#ifndef LocalLibs
#if UseTiff
#define LocalLibs	\			@@\
			$(GHOSTLIB)	  \	@@\
                        $(VEXPRLIB)	  \	@@\
			$(NUM_ANALLIB)    \	@@\
			$(DSPLLIB)	  \	@@\
			$(FILEFORMATLIB)  \	@@\
			$(GEO_SURFLIB)    \	@@\
			$(VIPLLIB)        \	@@\
			$(VUTILSLIB) 	  \	@@\
			$(VMATHLIB) 	  \	@@\
			$(VRASTLIB)	  \	@@\
			$(VGPARMLIB) 	  \	@@\
			$(VERRORLIB) 	  \	@@\
			$(TIFFLIB)
#else
#define LocalLibs	\			@@\
			$(GHOSTLIB)	  \	@@\
                        $(VEXPRLIB)	  \	@@\
			$(NUM_ANALLIB)    \	@@\
			$(DSPLLIB)	  \	@@\
			$(FILEFORMATLIB)  \	@@\
			$(GEO_SURFLIB)    \	@@\
			$(VIPLLIB)        \	@@\
			$(VUTILSLIB) 	  \	@@\
			$(VMATHLIB) 	  \	@@\
			$(VRASTLIB)	  \	@@\
			$(VGPARMLIB) 	  \	@@\
			$(VERRORLIB)
#endif
#endif

#ifndef LocalDependLibs
#if UseTiff
#define LocalDependLibs	\				@@\
			$(DEPENDGHOSTLIB)	\	@@\
                        $(DEPENDVEXPRLIB)	\	@@\
			$(DEPENDNUM_ANALLIB)    \	@@\
			$(DEPENDDSPLLIB)	\	@@\
			$(DEPENDFILEFORMATLIB)  \	@@\
			$(DEPENDGEO_SURFLIB)    \	@@\
			$(DEPENDVIPLLIB)        \	@@\
			$(DEPENDVUTILSLIB)	\	@@\
			$(DEPENDVMATHLIB)	\	@@\
			$(DEPENDVRASTLIB)	\	@@\
			$(DEPENDVGPARMLIB)	\	@@\
			$(DEPENDVERRORLIB)	\	@@\
			$(DEPENDTIFFLIB)
#else
#define LocalDependLibs	\				@@\
			$(DEPENDGHOSTLIB)	\	@@\
                        $(DEPENDVEXPRLIB)	\	@@\
			$(DEPENDNUM_ANALLIB)    \	@@\
			$(DEPENDDSPLLIB)	\	@@\
			$(DEPENDFILEFORMATLIB)  \	@@\
			$(DEPENDGEO_SURFLIB)    \	@@\
			$(DEPENDVIPLLIB)        \	@@\
			$(DEPENDVUTILSLIB)	\	@@\
			$(DEPENDVMATHLIB)	\	@@\
			$(DEPENDVRASTLIB)	\	@@\
			$(DEPENDVGPARMLIB)	\	@@\
			$(DEPENDVERRORLIB)
#endif
#endif

#ifndef XLocalLibs
#define XLocalLibs	\			@@\
                        $(XVDISPLAYLIB)  \	@@\
                        $(XVPLOTLIB)     \	@@\
                        $(XVGRAPHICSLIB) \	@@\
                        $(XVFORMSLIB)    \	@@\
                        $(XVUTILSLIB)
#endif

#ifndef XLocalDependLibs
#define XLocalDependLibs	\			@@\
                        $(DEPENDXVDISPLAYLIB)	\	@@\
                        $(DEPENDXVPLOTLIB)	\	@@\
                        $(DEPENDXVGRAPHICSLIB)	\	@@\
                        $(DEPENDXVFORMSLIB)	\	@@\
                        $(DEPENDXVUTILSLIB)
#endif

#if HasFortran
#ifndef ForLocalLibs
#define ForLocalLibs	\			@@\
			$(LINPACKLIB)	\	@@\
			$(EISPACKLIB)
#endif
#ifndef ForLocalDependLibs
#define ForLocalDependLibs	\			@@\
			$(DEPENDLINPACKLIB)	\	@@\
			$(DEPENDEISPACKLIB)
#endif
#else
#define ForLocalLibs	/**/
#define ForLocalDependLibs /**/
#endif



X_LOCAL_LIBRARIES = XLocalLibs
 LOCAL_LIBRARIES  = LocalLibs
FOR_LOCAL_LIBRARIES = ForLocalLibs
    SYS_LIBRARIES = TransportLibs SysLibs
      X_LIBRARIES = XLibs
FOR_SYS_LIBRARIES = ForSysLibs
  EXTRA_LIBRARIES = ExtraLibs

X_LOCAL_DEP_LIBRARIES = XLocalDependLibs
LOCAL_DEP_LIBRARIES = LocalDependLibs
FOR_LOCAL_DEP_LIBRARIES = ForLocalDependLibs
