KCOM Beginning of Khoros site configuration file - Site.def.

/*
 * define where the Khoros bins, libs and man pages are to go.
 * the default is KHOROS_HOME/bin KHOROS_HOME/lib and KHOROS_HOME/man
 *
 * we recommend these be left as is
 */

#ifndef SrcTop
#define SrcTop KHOROS_HOME/src
#endif

#undef BinDir
#define BinDir KHOROS_HOME/bin

#undef KLibDir
#define KLibDir KHOROS_HOME/lib

#undef IncRoot
#define IncRoot KHOROS_HOME/include

#ifndef ManDir
#define ManDir KHOROS_HOME/man/man1
#endif
#ifndef LibManDir
#define LibManDir KHOROS_HOME/man/man3
#endif

/*
 * Specify the include directory of X include files
 * default is to look in /usr/include for the X11 directory
 */
#ifndef XIncludes
#define XIncludes /**/
#endif

/*
 * specify the loader prefix for lib paths to search during loading.
 * best to change this in the machine.cf file rather than here.
 */
#ifndef LoaderLibPrefix
#define LoaderLibPrefix -L
#endif

/*
 * specify where basename lives on your machine. Best to change this
 * in the machine.cf file
 */
#ifndef BaseName
#define BaseName /usr/bin/basename
#endif

/*
 * specify the load flags for bins
 */
#ifndef InstBinFlags
#define InstBinFlags -m 0775
#endif

/* 
 * do you want your binaries striped when installing them to bin
 */
#ifndef StripInstalledPrograms
#define StripInstalledPrograms YES
#endif


/*
 *  if your /tmp space is less than a 1meg, you should 
 * probably set this to NO
 */
#ifndef HasLargeTmp
#define HasLargeTmp YES
#endif


/*
 * If you want to use GCC,  set HasGcc to YES
 */
#ifndef HasGcc
#define HasGcc NO
#endif

#if HasGcc
#ifndef CcCmd
#define CcCmd gcc -traditional -fstrength-reduce -fpcc-struct-return 
#endif
#endif

/*
 * Specify the program loader for your machine. Default is to use CC as
 * defined to be cc or gcc.
 */
#ifndef LdCmd
#define LdCmd $(CC)
#endif

/*
 * Specify the default YFLAGS to re-generate (update) the y.tab.h everytime
 * the {file}.y is yacc'ed.
 */
#ifndef DefaultYFlags
#define DefaultYFlags -d
#endif

/*
 * Specify the default LFLAGS for lex to use
 */
#ifndef DefaultLFlags
#define DefaultLFlags -n
#endif

/* 
 * the following should have already been set in the machine.cf file.
 * it is best to make changes in the machine.cf file. The following
 * are in case one gets deleted in the machine.cf file.
 */

/*
 * does your machine have fortran? 
 */
#ifndef HasFortran
#define HasFortran YES
#endif

/*
 * set the fortran compiler
 */
#ifndef FortranCmd
#define FortranCmd f77 -O
#endif

