IMAKEFILE = lib

TOOLBOX = 

SRCS =

OBJS =

YSRCS =

LSRCS =

FSRCS =

FOBJS =

HEADERS =

LIBRARY_NAME =

/* the following field are intentionally left commented.  Use the flags       */
/* if you wish to override the defaults assigned in the system configuration  */
/* files.								      */

/* STD_INCLUDES = */

/* LIBCDEBUGFLAGS = */

#include <Lib.template>
