 /*
  * Khoros: $Id: lvfrog.c,v 1.2 1991/10/01 23:18:22 khoros Exp $
  */

#if !defined(lint) && !defined(SABER)
static char rcsid[] = "Khoros: $Id: lvfrog.c,v 1.2 1991/10/01 23:18:22 khoros Exp $";
#endif

 /*
  * $Log: lvfrog.c,v $
 * Revision 1.2  1991/10/01  23:18:22  khoros
 * HellPatch2
 *
  */

/*
 *----------------------------------------------------------------------
 *
 * Copyright 1991, University of New Mexico.  All rights reserved.
 * Permission to copy and modify this software and its documen-
 * tation only for internal use in your organization is hereby
 * granted, provided that this notice is retained thereon and
 * on all copies.  UNM makes no representations as to the sui-
 * tability and operability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 * 
 * UNM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
 * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FIT-
 * NESS.  IN NO EVENT SHALL UNM BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY OTHER DAMAGES WHAT-
 * SOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER
 * IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
 * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PER-
 * FORMANCE OF THIS SOFTWARE.
 * 
 * No other rights, including, for example, the right to redis-
 * tribute this software and its documentation or the right to
 * prepare derivative works, are granted unless specifically
 * provided in a separate license agreement.
 *---------------------------------------------------------------------
 */

#include "unmcopyright.h"        /* Copyright 1991 by UNM */

/*>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>  <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 >>>>
 >>>>         File Name: lvfrog.c
 >>>>
 >>>>      Program Name: vfrog
 >>>>
 >>>> Date Last Updated: Wed Sep 25 16:30:19 1991 
 >>>>
 >>>>          Routines: lvfrog - the library call for vfrog
 >>>>
 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>   <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<*/


#include "vinclude.h"


/* -library_includes */
/* -library_includes_end */


/****************************************************************
*
* Routine Name: lvfrog - library call for vfrog
*
* Purpose:
*    
*    Prints a variable number of 'RIBBITS'
*    
*    

* Input:
*    
*    c - integer specifying the number of croaks.
*    
*    

* Output:
*    
*    returns (TRUE)...this clever routine never fails.
*    
*    

*
* Written By: Kermit The Frog
****************************************************************/


/* -library_def */
int lvfrog(croaks)
int croaks;

/* -library_def_end */

/* -library_code */
{
        int i;
        for (i = 0; i < croaks; i++)
        {
           if ((i % 2) == 0)
             fprintf(stderr, "RIBBIT! RIBBIT!  CROAK! CROAK!\n");
           else
             fprintf(stderr, "(ribbit! ribbit!  croak! croak!)\n");
        }
        fprintf(stderr, "\n\n>> Splash! <<\n\n");

        return(TRUE);
}
/* -library_code_end */
