KCOM Beginning of the Khoros data transport definitions

/* 
 *  This file is included after Khoros.tmpl, Site.def and
 *  the Library.def file and just before the Imakefile.
 *  This file can be modified to define data transport
 *  definitions and which libraries to link against.
 *  The following is a list of the defines used for currently
 *  supported data transports:
 *
 *      KFILE                   - Standard file system transport
 *      KSHM                    - shared memory
 *      KSUNVM                  - sun virtual memory
 *      KTLI                    - sysV transport layer interface
 *      KPIPE                   - Pipes
 *      KSOCKET                 - bsd Sockets
 *      KSTREAM                 - Named pipes
 *      KSUNRPC                 - Sun's remote procedure call
 *      KAPOLLORPC              - Apollo's remote procedure call
 *
 */

#if UseFile				/* Standard file system transport */
#   define _file /**/			/* Library to load against */
#   define _dfile -DKFILE		/* Transport define */
#else
#   define _file /**/
#   define _dfile /**/
#endif

#if UseSockets				/* bsd Sockets */
#   define _sock /**/
#   define _dsock -DKSOCKET
#else
#   define _sock /**/
#   define _dsock /**/
#endif

#if UseSharedMem			/* shared memory */
#   define _shmem /**/
#   define _dshmem -DKSHM
#else
#   define _shmem /**/
#   define _dshmem /**/
#endif

#if UseSunVirMem			/* sun virtual memory */
#   define _ssm /**/
#   define _dssm -DKSUNVM
#else
#   define _ssm /**/
#   define _dssm /**/
#endif

#if UsePipes				/* Pipes */
#   define _pipe /**/
#   define _dpipe -DKPIPE
#else
#   define _pipe /**/
#   define _dpipe /**/
#endif

#if UseStream				/* Named pipes */
#   define _stream /**/
#   define _dstream -DKSTREAM
#else
#   define _stream /**/
#   define _dstream /**/
#endif

#if UseSunRPC				/* Sun's remote procedure call */
#   define _srpc /**/
#   define _dsrpc -DKSUNRPC
#else
#   define _srpc /**/
#   define _dsrpc /**/
#endif

#if UseKTLI				/* sysV transport layer interface */
#   define _ktli /**/
#   define _dktli -DKTLI
#else
#   define _ktli /**/
#   define _dktli /**/
#endif

#if UseApolloRPC			/* Apollo's remote procedure call */
#   define _arpc /**/
#   define _darpc -DKAPOLLORPC
#else
#   define _arpc /**/
#   define _darpc /**/
#endif

#ifndef TransportLibs
#  define TransportLibs _file _sock _shmem _ssm _pipe _stream _srpc _ktli _arpc
#endif

#ifndef TransportDefines
#  define TransportDefines _dfile _dsock _dshmem _dssm _dpipe _dstream _dsrpc _dktli _darpc
#endif

