/**/## Beginning of the Khoros generic toolbox configuration file 

/* 
 *  This file is included in the Makefile after Khoros.tmpl, 
 *  Site.def, Library.def file and just before the Imakefile.
 *  This file can be modified to define other Toolbox definitions.
 */


/* assign the TB_NAME variable to the name of your particular toolbox.
 * change "toolbox_name" to the name of your toolbox. Note, name
 * MUST be in UPPER CASE.
 */
TB_NAME = toolbox_name


/* Set locations of bin and lib directories in your particular toolbox.
 * The default is toolbox_home/bin and toolbox_home/lib.
 */
LIBDIR = $(TB_NAME)/lib
BINDIR = $(TB_NAME)/bin


/* Set location of include files for your toolbox. You should not have
 * to change this symbol.
 * The default is toolbox_home/include.
 * Note, /usr/include and $KHOROS_HOME/include will automatically be 
 * searched. You do not have to specify these.
 */
TOOLBOXINCLUDE = -I$(TB_NAME)/include


/* Set library loading search path.You should not have
 * to change this symbol.
 * The default is toolbox_home/LIBDIR.
 * Note, /usr/lib and $KHOROS_HOME/lib will automatically be searched.
 * You do not have to specify these.
 */
TOOLBOXLIBDIR = -L$(LIBDIR)


/* Any special defines for your toolbox (eg, #ifdef DEBUG) 
 * can be set here (eg, -DDEBUG) 
 */
TOOLBOXDEFINES = /**/


/* List C libraries created (by you) in the toolbox.
 * These are vroutine or utility libraries. Note, each library
 * in the list must be preceded by a -l. 
 * (eg. TOOLBOX_LIBRARIES = -lutil -lfrogs
 *
 * Also, list the full path to the libraries for the
 * TOOLBOX_DEP_LIBRARIES symbol. This allows your programs to depend
 * on a library. This is if a library changes, then make will know
 * to reload your program. An example of how to set this symbol is:
 * TOOLBOX_DEP_LIBRARIES = $(LIBDIR)/libutil.a $(LIBDIR)/libfrogs.a
 */
TOOLBOX_LIBRARIES = /**/
TOOLBOX_DEP_LIBRARIES = /**/


/* List all FORTRAN libraries created (by you) in the toolbox.
 * follow the same concept for listing the libraries as described
 * for the TOOLBOX_LIBRARIES and TOOLBOX_DEP_LIBRARIES above.
 */
FOR_TOOLBOX_LIBRARIES = /**/
FOR_TOOLBOX_DEP_LIBRARIES = /**/


/* List Xlib or X Toolkit dependant libaries created (by you) in the toolbox.
 * follow the same concept for listing the libraries as described
 * for the TOOLBOX_LIBRARIES and TOOLBOX_DEP_LIBRARIES above.
 */
X_TOOLBOX_LIBRARIES = /**/
X_TOOLBOX_DEP_LIBRARIES = /**/

/*
 * You may override any symbols previous defined in the imake system if
 * you wish. You should never have to override any sybmols.
 */
