/*
 *----------------------------------------------------------------------
 *
 * Copyright 1991, University of New Mexico.  All rights reserved.
 * Permission to copy and modify this software and its documen-
 * tation only for internal use in your organization is hereby
 * granted, provided that this notice is retained thereon and
 * on all copies.  UNM makes no representations as to the sui-
 * tability and operability of this software for any purpose.
 * It is provided "as is" without express or implied warranty.
 * 
 * UNM DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
 * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FIT-
 * NESS.  IN NO EVENT SHALL UNM BE LIABLE FOR ANY SPECIAL,
 * INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY OTHER DAMAGES WHAT-
 * SOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER
 * IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS
 * ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PER-
 * FORMANCE OF THIS SOFTWARE.
 * 
 * No other rights, including, for example, the right to redis-
 * tribute this software and its documentation or the right to
 * prepare derivative works, are granted unless specifically
 * provided in a separate license agreement.
 *---------------------------------------------------------------------
 */

#include "unmcopyright.h"        /* Copyright 1991 by UNM */


/*>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>  <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 >>>>
 >>>>         File Name: example2.h
 >>>>            Author: Danielle Argiro
 >>>> Date Last Updated: Wed Apr 24 09:50:38 1991
 >>>> 
 >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>   <<<<<<<<<<<<<<<<<<<<<<<<<<<<<<*/

#ifndef _example2_h_
#define _example2_h_

#include "xvinclude.h"


/* -include_includes */
#include "xvforms.h"
#include "form_info.h"
#include "xvgraphics.h"
#include "xvdisplay.h"
/* -include_includes_end */

char	**av,		/* argv and argc used by gparams */
	*program,	/* a pointer to the program name argv[0] */
	*calloc();
int	ac;

/****************************************************************
*
*                    example2 Argument Structure
*
****************************************************************/

typedef struct _example2  {

/*
 *  Input Image (Optional infile)
 */
char	*i;     	/* Input Image FILENAME */
int	 i_flag;	/* Input Image FLAG */

/*
 *  width of viewport (Optional integer)
 */
int	 w;    	/* width of viewport INT */
int	 w_flag;	/* width of viewport FLAG */

/*
 *  height of viewport (Optional integer)
 */
int	 h;    	/* height of viewport INT */
int	 h_flag;	/* height of viewport FLAG */

}  example2_struct;

example2_struct *example2;

/* -include_additions */

Display *display;
DisplayStructure *xvdisplay;

Widget workspace;       /* workspace child of viewport in which 
                           to display image */

/* -include_additions_end */

/* -include_macros */
/* -include_macros_end */

#endif
